__all__ = ["MEASUREMENT_NAMES", "MEASUREMENT_UNITS"]


MEASUREMENT_NAMES = (
        ("LENGTH", "LENGTH"),
        ("WIDTH", "WIDTH"),
        ("HEIGHT", "HEIGHT"),
        ("WEIGHT", "WEIGHT"),
        ("WAIST", "WAIST"),
        ("BUST", "BUST"),
        ("CHEST", "CHEST"),
        ("RADIUS", "RADIUS"),
        ("DIAMETER", "DIAMETER"),
        ("VOLUME", "VOLUME"),
        ("SHOULDER", "SHOULDER"),
        ("COLLAR", "COLLAR"),
        ("SLEEVE", "SLEEVE"),
        ("CUFF", "CUFF"),
        ("THICKNESS", "THICKNESS"),
        ("INSEAM", "INSEAM")
)


MEASUREMENT_UNITS = (
        ("AMPERE", "AMPERE"),
        ("CELCIUS", "CELCIUS"),
        ("CENTIMETER", "CENTIMETER"),
        ("GALLON", "GALLON"),
        ("KELVIN", "KELVIN"),
        ("METER", "METER"),
        ("MILLIMETER", "MILLIMETER"),
        ("LITRE", "LITRE"),
        ("MILLILITRE", "MILLILITRE")
)